@@ -103,12 +103,8 @@ extern double atan2 ___P ((double, double));
 #include "dummypwd.h"
 #endif
 
-#if ENABLE_NLS
-#include <libintl.h>
+#include "gettext.h"
 #define _(String) gettext (String)
-#else
-#define _(String) String
-#endif
 
 #if HAVE_LC_MESSAGES
 #include <locale.h>
@@ -326,8 +322,6 @@ typedef struct cached_font_info_st CachedFontInfo;
 
 extern char *program;
 extern FILE *ofp;
-extern char *version_string;
-extern char *ps_version_string;
 extern char *date_string;
 extern struct tm run_tm;
 extern struct tm mod_tm;
