@@ -58,8 +58,6 @@ static void version ();
 char *program;			/* Program's name, used for messages. */
 FILE *ofp = NULL;		/* Output file. */
 void *printer_context;		/* Context for the printer. */
-char *version_string = NULL;	/* Enscript's version string. */
-char *ps_version_string = NULL;	/* Version string for PS procsets. */
 char *date_string = NULL;	/* Preformatted time string. */
 struct tm run_tm;		/* Time when program is run. */
 struct tm mod_tm;		/* Last modification time for current file. */
@@ -946,19 +944,6 @@ main (int argc, char *argv[])
   /* Make getopt_long() to use our modified programname. */
   argv[0] = program;
 
-  /* Create version strings. */
-
-  buffer_clear (&buffer);
-  buffer_append (&buffer, "GNU ");
-  buffer_append (&buffer, PACKAGE);
-  buffer_append (&buffer, " ");
-  buffer_append (&buffer, VERSION);
-  version_string = buffer_copy (&buffer);
-
-  ps_version_string = xstrdup (VERSION);
-  cp = strrchr (ps_version_string, '.');
-  *cp = ' ';
-
   /* Create the default TOC format string.  Wow, this is cool! */
   /* xgettext:no-c-format */
   toc_fmt_string = _("$3v $-40N $3% pages $4L lines  $E $C");
@@ -1100,10 +1085,8 @@ _("This is probably an installation error.  Please, try to rebuild:")));
 		  ERROR ((stderr, _("\tmake")));
 		  ERROR ((stderr, _("\tmake check")));
 		  ERROR ((stderr, _("\tmake install")));
-		  ERROR ((stderr,
-_("or set the environment variable `ENSCRIPT_LIBRARY' to point to your")));
-		  ERROR ((stderr,
-_("library directory.")));
+		  ERROR ((stderr, _("or set the environment variable `ENSCRIPT_LIBRARY'"
+			" to point to your library directory.")));
 		  exit (1);
 		}
 
@@ -1771,8 +1754,15 @@ name             width\theight\tllx\tlly\turx\tury\n\
 	real_total_pages = total_pages;
 
       /* We did something, tell what.  */
-      MESSAGE (0, (stderr, _("[ %d pages * %d copy ]"), real_total_pages,
-		   num_copies));
+      char message[80];
+      snprintf(message, sizeof message, "%s%s%s%s%s",
+	       "[ ",
+	       ngettext("%d page", "%d pages", real_total_pages),
+	       " * ",
+	       ngettext("%d copy", "%d copies", num_copies),
+	       " ]");
+      MESSAGE (0, (stderr, message, real_total_pages, num_copies));
+
       if (output_file == OUTPUT_FILE_NONE)
 	MESSAGE (0, (stderr, _(" sent to %s\n"),
 		     printer ? printer : _("printer")));
@@ -1783,7 +1773,7 @@ name             width\theight\tllx\tlly\turx\tury\n\
 	{
 	  retval |= 2;
 	  MESSAGE (0, (stderr,
-		       ngettext("1 line was %s\n",
+		       ngettext("%d line was %s\n",
 				"%d lines were %s\n",
 				num_truncated_lines),
 		       num_truncated_lines,
@@ -1795,7 +1785,7 @@ name             width\theight\tllx\tlly\turx\tury\n\
 	{
 	  retval |= 4;
 	  MESSAGE (0, (stderr,
-		       ngettext("1 character was missing\n",
+		       ngettext("%d character was missing\n",
 				"%d characters were missing\n",
 				num_missing_chars),
 		       num_missing_chars));
@@ -1810,7 +1800,7 @@ name             width\theight\tllx\tlly\turx\tury\n\
 	{
 	  retval |= 8;
 	  MESSAGE (0, (stderr,
-		       ngettext("1 non-printable character\n",
+		       ngettext("%d non-printable character\n",
 				"%d non-printable characters\n",
 				num_non_printable_chars),
 		       num_non_printable_chars));
@@ -2016,7 +2006,7 @@ handle_options (int argc, char *argv[])
       int i;
 
       c = getopt_long (argc, argv,
-		       "#:123456789a:A:b:BcC::d:D:e::E::f:F:gGhH::i:I:jJ:kKlL:mM:n:N:o:Op:P:qrRs:S:t:T:u::U:vVW:X:zZ",
+		       "#:123456789a:A:b:BcC::d:D:e::E::f:F:gGhH::i:I:jJ:kKlL:mM:n:N:o:Op:P:qrRs:S:t:T:u::U:vVw:W:X:zZ",
 		       long_options, &option_index);
 
       if (c == -1)
@@ -2534,16 +2524,16 @@ Mandatory arguments to long options are mandatory for short options too.\n\
   -b, --header=HEADER        set page header\n\
   -B, --no-header            no page headers\n\
   -c, --truncate-lines       cut long lines (default is to wrap)\n\
-  -C, --line-numbers[=START]\n\
+  -C[START], --line-numbers[=START]\n\
                              precede each line with its line number\n\
   -d                         an alias for option --printer\n\
   -D, --setpagedevice=KEY[:VALUE]\n\
                              pass a page device definition to output\n\
-  -e, --escapes[=CHAR]       enable special escape interpretation\n"),
+  -e[CHAR], --escapes[=CHAR]       enable special escape interpretation\n"),
           program);
 
   printf (_("\
-  -E, --highlight[=LANG]     highlight source code\n"));
+  -E[LANG], --highlight[=LANG]     highlight source code\n"));
 
   printf (_("\
   -f, --font=NAME            use font NAME for body text\n\
@@ -2552,7 +2542,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
   -G                         same as --fancy-header\n\
       --fancy-header[=NAME]  select fancy page header\n\
   -h, --no-job-header        suppress the job header page\n\
-  -H, --highlight-bars=NUM   specify how high highlight bars are\n\
+  -H[NUM], --highlight-bars[=NUM]  specify how high highlight bars are\n\
   -i, --indent=NUM           set line indent to NUM characters\n\
   -I, --filter=CMD           read input files through input filter CMD\n\
   -j, --borders              print borders around columns\n\
@@ -2586,7 +2576,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
   -t, --title=TITLE          set banner page's job title to TITLE.  Option\n\
                              sets also the name of the input file stdin.\n\
   -T, --tabsize=NUM          set tabulator size to NUM\n\
-  -u, --underlay[=TEXT]      print TEXT under every page\n\
+  -u[TEXT], --underlay[=TEXT]      print TEXT under every page\n\
   -U, --nup=NUM              print NUM logical pages on each output page\n\
   -v, --verbose              tell what we are doing\n\
   -V, --version              print version number\n\
@@ -2643,7 +2633,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
   --word-wrap                wrap long lines from word boundaries\n\
 "));
 
-  printf (_("\nReport bugs to %s.\n"), PACKAGE_BUGREPORT);
+  printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
 }
 
 
@@ -2651,10 +2641,12 @@ static void
 version ()
 {
   printf ("%s\n\
-Copyright (C) 2003 Markku Rossi.\n\
-GNU enscript comes with NO WARRANTY, to the extent permitted by law.\n\
-You may redistribute copies of GNU enscript under the terms of the GNU\n\
-General Public License.  For more information about these matters, see\n\
-the files named COPYING.\n",
-	  version_string);
+Copyright (C) 1995-2003, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.\n\
+%s comes with NO WARRANTY, to the extent permitted by law.\n\
+You may redistribute copies of %s under the terms of the GNU\n\
+General Public License, version 3 or, at your option, any later version.\n\
+For more information about these matters, see the files named COPYING.\n",
+	  PACKAGE_STRING,
+	  PACKAGE_NAME,
+	  PACKAGE_NAME);
 }
